#!/bin/bash 
#===============================================================================
#
#          FILE: collectLogs.no_sshpass.sh
#
#         USAGE: ./collectLogs.no_sshpass.sh
#
#   DESCRIPTION: Collects Logs directory from linux based NAC/NES/NAG systems by connecting to the remote machine using SSH to tar the files and then copy them to your workstation using scp. 
#
#   NOTES:
#       This script assumes that you do NOT get prompted for a password when running SSH and SCP commands from the machine where this 
#           script is running -> to the EOF list of hosts. 
#           If you are prompted for passwords then the script will still work but it will prompt you every time a password is needed (twice per host).
#           If you are prompted for a password, and use the same password across all hosts, then using the collectLogs.sshpass.sh script is recommended.
#
#       This script assumes that you are able to connect directly to the <EOF list of hosts> with the user that owns the nolio_home folder (defined below).
#
#       If any of the following items are different across the machines you want to collect data from then you will need to copy the script & adjust the necessary variables:
#           - nolio_user
#           - nolio_home
#               For example: 
#                   It is common for the NAC and NES to share folder install paths. So you could use this one script to collect logs from your nac and all nes. However, 
#                   agents are not installed (by default) to the same folder location as nac and nes. So if you're collecting files from agents then you will 
#                   need to copy the script and adjust the nolio_home variable. 
#
#   REQUIREMENTS:
#       1. the script be run from a mac or linux machine.
#       2. the ssh and scp commands are available.
#         
#===============================================================================

set -eu -o pipefail

function ensure_app_runnable() {
    app=${1+$1}
    which $app >/dev/null || {
        echo "App $app not found on the PATH"
        exit 1
    }
}

ensure_app_runnable ssh
ensure_app_runnable scp

nolio_user=noliouser
nolio_home="/opt/CA/ReleaseAutomationServer"

timestamp=$(date +%Y-%m-%d-%H-%M-%S)

while read host
do
    printf '\n%s\n' "Gathering data for: ${host}"

    # Archive filename
    arname="nolio_${host}_${timestamp}.tar.gz"
    
    # Used with sshkeys that don't prompt for password/passphrase
    # NOTE: the -n redirects stdin from /dev/null. If this is not done then SSH would also read stdin and eat the stdin used by reading the heredoc. Some other options are discussed here: 
    # https://unix.stackexchange.com/questions/107800/using-while-loop-to-ssh-to-multiple-servers

    # Connect to remote host and tar the nimi_config.xml and logs folder.
    ssh -n ${nolio_user}@${host} "cd ${nolio_home} && tar zcf ${arname} conf/nimi_config.xml ./logs"

    # Copy the tar file from the remote machine to the local folder where this script is running.
    scp ${nolio_user}@${host}:${nolio_home}/${arname} .

done <<EOF
myhost1.fqdn
myhost2.resolvable.name.or.ip
EOF
